version 14.1
set more off
  quietly log
  local logon = r(status)
  if "`logon'" == "on" {
	log close
	}
log using exercise01discrete, text replace

/*		****************************************************************	*/
/* 		Author:			Frederick J. Boehmke								*/
/*		Date:			May 2, 2019											*/
/*      File:			exercise01discrete.do								*/
/*		Purpose:		Controlling for duration dependence in discrete 	*/
/*						EHA using time, FEs, and splines. 					*/
/*      Input File:		exercise01discrete.dta								*/
/*      Output File:	exercise01discrete.log,								*/
/*						exercise01discrete-compare-XXX.gph					*/
/*		****************************************************************	*/


	/************************************************************/
	/* First, open the data and code the adoption variable.		*/
	/* adopt_year gives the year of adoption - convert to 		*/
	/* indicator for EHA analysis.								*/
	/************************************************************/

	
use exercise01discrete, clear
	
  describe
  summarize
		
generat adopt_hc = .
replace adopt_hc = 1 if year == adopt_year
replace adopt_hc = 0 if year < adopt_year & !missing(adopt_year)
replace adopt_hc = 0 if missing(adopt_year)
	
		/* This variable defines the risk set. */

generat risk_hc = 1 if year <= adopt_year & !missing(adopt_year)
replace risk_hc = 0 if year >  adopt_year & !missing(adopt_year)
replace risk_hc = 1 if missing(adopt_year)

		/* Check the adoption years by state. */

table state if adopt_hc == 1, c(mean year mean adopt_year)


	/*********************/
	/* Explore the data. */
	/*********************/

		/* Count of adoptions and size of risk set each year. */
	
table year, contents(sum adopt_hc count adopt_hc)
	
graph bar (sum) adopt_hc, scheme(s1color) over(year, label( labsize(small) angle(90))) ///
	ytitle("") ///
	title(Number of Adoptions per Year)
	
graph bar (mean) adopt_hc, scheme(s1color) over(year, label( labsize(small) angle(90))) ///
	ytitle("") ///
	title(Hazard Rate)
	
graph bar (count) adopt_hc, scheme(s1color) over(year, label( labsize(small) angle(90))) ///
	ytitle("") ///
	title(States at Risk each Year (Survival Function))
	

	/******************************/
	/* Run some basic EHA models. */
	/******************************/


logit   adopt_hc citi6013 totpop rpcpinc, cluster(stateno)
probit  adopt_hc citi6013 totpop rpcpinc, cluster(stateno)
cloglog adopt_hc citi6013 totpop rpcpinc, cluster(stateno)


  	/*********************************************************************/
	/* Now address possible duration dependence - create time variables. */
  	/*********************************************************************/

		/* Generate the pieces for a cubic polynomial of time. */

generat time = year - 1978
generat time_sq = time^2
generat time_cube = time^3

	
	/****************************************/
	/* Then run associated models and 		*/
	/* store the results to make a table.	*/
	/****************************************/

	
logit adopt_hc citi6013 totpop rpcpinc, cluster(stateno)

  estimates store time_0

logit adopt_hc citi6013 totpop rpcpinc time, cluster(stateno)

  estimates store time_1

logit adopt_hc citi6013 totpop rpcpinc time time_sq, cluster(stateno)

  estimates store time_2

logit adopt_hc citi6013 totpop rpcpinc time time_sq time_cube, cluster(stateno)

  estimates store time_3
	
	
	/****************************************/
	/* Repeat for year fixed effects.	*/
	/****************************************/

		/* Use factor variable notation to include year fixed effects. */
  
logit adopt_hc citi6013 totpop rpcpinc i.year, cluster(stateno)

  estimates store time_fe

		/* Make a table with these results. */
  
estimates table time_0 time_1 time_2 time_3 time_fe, /// 
	b(%9.3f) se ///
	modelwidth(7) varwidth(40) /// 
	varlabel ///
	stats(N ll) stfmt(%9.3f) 
	
	
	/********************************/
	/* Repeat for year splines.		*/
	/********************************/

		/* Generate a linear spline with 3 knots at tertiles. */
  
mkspline _spline 3 = time if !missing(adopt_hc), pctile displayknots
	
		/* Let's see what we got. */
		
  table time, c(mean _spline1 mean _spline2 mean _spline3)
  twoway line _spline* time, sort
  
logit adopt_hc citi6013 totpop rpcpinc _spline*, cluster(stateno)

		/* Now redo setting the knots by hand. */

drop _spline*

mkspline _spline1 9 _spline2 18 _spline3 = time

  table time, c(mean _spline1 mean _spline2 mean _spline3)
  twoway line _spline* time, sort
  
logit adopt_hc citi6013 totpop rpcpinc _spline*, cluster(stateno)

  estimates store time_spline1

		/* Redo our table with these results. */
  
estimates table time_0 time_1 time_2 time_3 time_fe time_spline1, /// 
	b(%9.3f) se ///
	modelwidth(7) varwidth(40) /// 
	varlabel ///
	stats(N ll) stfmt(%9.3f) 

	
	/********************************/
	/* Now try a cubic spline.		*/
	/********************************/

	
mkspline _spline_cu = time, cubic nknots(4) displayknots	

		/* Let's see what we got. */
		
  table time, c(mean _spline_cu1 mean _spline_cu2 mean _spline_cu3)
  twoway line _spline_cu* time, sort
  
logit adopt_hc citi6013 totpop rpcpinc _spline_cu*, cluster(stateno)

  estimates store time_spline_cu1


	/****************************************/
	/* Let's make a graph of those splines.	*/
	/****************************************/

		/* -collapse- to get one observation per year. */

collapse (mean) citi6013 totpop rpcpinc _spline* time*, by(year)
  
		/* Use same value of control variables to hold constant. */
  
	egen citi6013_mean 	= mean(citi6013) 
	egen totpop_mean 	= mean(totpop) 
	egen rpcpinc_mean 	= mean(rpcpinc) 

	replace citi6013 	= citi6013_mean
	replace totpop 		= totpop_mean
	replace rpcpinc 	= rpcpinc_mean

	drop *_mean
 
	table time, c(mean _spline1 mean _spline2 mean _spline3)
	  
		/* First predict at latent ystar scale to see linear spline effect. */
  
estimates restore time_spline1

predict ystarhat_spline, xb

twoway line ystarhat_spline time	

		/* Translate into probability scale to see in terms of the outcome. */
  
predict pihat_spline, pr

twoway line pihat time	

		/* Access the fixed effects results. */
	
estimates restore time_fe

  predict ystarhat_fe, xb
  predict pihat_fe, pr
	
		/* Access the cubic polynomial results. */
	
estimates restore time_3 
	
  predict ystarhat_3, xb
  predict pihat_3, pr
	
		/* Access the cubic spline results. */
	
estimates restore time_spline_cu1
  
  predict ystarhat_spline_cu, xb
  predict pihat_spline_cu, pr
	
		/* Graph them all to compare. */

  label variable ystarhat_spline_cu "Cubic Spline"
  label variable ystarhat_spline 	"Linear Spline"
  label variable ystarhat_fe	 	"Fixed Effects"
  label variable ystarhat_3 		"Cubic Polynomial"
		
  label variable pihat_spline_cu	"Cubic Spline"
  label variable pihat_spline 		"Linear Spline"
  label variable pihat_fe	 		"Fixed Effects"
  label variable pihat_3 			"Cubic Polynomial"
		
  twoway line ystarhat_spline ystarhat_spline_cu ystarhat_3 time, scheme(s1color) ///
	|| 	connected ystarhat_fe time, msize(small) ///
		xtitle("Time") ///
		ylabel(#5, grid) ///
		legend(rows(1)) ///
		saving(exercise01discrete-compare-ystar, replace)	

  twoway line pihat_spline pihat_spline_cu pihat_3 time, scheme(s1color) ///
	|| 	connected pihat_fe time, msize(small) ///
		xtitle("Time") ///
		ylabel(#5, grid) ///
		legend(cols(1) size(small) ring(0) bplace(nw)) ///
		saving(exercise01discrete-compare-pi, replace)	
  
  
log close
clear
exit, STATA
