version 14.1
set more off
  quietly log
  local logon = r(status)
  if "`logon'" == "on" { 
	log close 
	}
log using exercise02continuous, text replace

/*		************************************************************	*/
/* 		Author:			Frederick J. Boehmke							*/
/*		Date:			May 2, 2019										*/
/*      File:			exercise02continuous.do							*/
/*		Purpose:		Introduction of continuous-time duration model 	*/
/*						duration models and the -st- suite of commands. */
/*						Compare parametric dsitributions with the Cox	*/
/*						models and explore right censoring.				*/
/*  	Input File:		exercise02continuous.dta						*/
/*  	Output File:	exercise02continuous.log,						*/
/*  		    		exercise02continuous.txt,						*/
/*      				exercise02continuous-nocens.dta,				*/
/*      				exercise02continuous-cens.dta,					*/
/*      				exercise02continuous.gph						*/
/*		Requires:		estout.ado										*/
/*		************************************************************	*/

		/* Open data set. */

use exercise02continuous, clear


	/********************************************************************/
	/* Declare the data to be survival time and explore -st- commands.	*/
	/********************************************************************/
	
stset durat

		/* There are various commands to explore the data. */

  stsum
  stdescribe
  
  sts graph, survival
  sts graph, hazard
  sts graph, survival ci
	
		/* We can also estimate models. Note we don't specify the dependent 	*/
		/* variable since we already did when we -stset- the data. 				*/

streg invest fract polar numst2 format eltime2 caretk2, distribution(exponential)

		/* Get coefficients in different formats. */
		
streg invest fract polar numst2 format eltime2 caretk2, distribution(exponential) nohr
		
		/* This is the form for time to failure. */
		
streg invest fract polar numst2 format eltime2 caretk2, distribution(exponential) time
		
		/* -stcurve- helps us interpret the model. */
		
stcurve, survival
stcurve, hazard

stcurve, hazard at1(polar=3) at2(polar=35)
		
		/* We can repeat the estimation for a Weibull model. */
		/* Note how the reported coefficients change.        */
	
streg invest fract polar numst2 format eltime2 caretk2, distribution(weibull)

		/* Get coefficients in different formats. */
		
streg invest fract polar numst2 format eltime2 caretk2, distribution(weibull) nohr
		
		/* This is the form for time to failure. */
		
streg invest fract polar numst2 format eltime2 caretk2, distribution(weibull) time
		
		/* -stcurve- helps us interpret the model. */
		
stcurve, survival
stcurve, hazard

stcurve, hazard at1(polar=3) at2(polar=35)
		
		/* Here is how to estimate a Cox model. */
		/* It does not permit the -time- option. */
	
stcox invest fract polar numst2 format eltime2 caretk2, nohr
	
stcurve, survival
stcurve, hazard

stcurve, hazard at1(polar=3) at2(polar=35)

	
	/********************************************/
	/* Estimate and compare a series of models.	*/
	/* We do not account for right censoring.   */
	/********************************************/
	
	
streg invest fract polar numst2 format eltime2 caretk2, dist(exp) time

  estimates store exp1

streg invest fract polar numst2 format eltime2 caretk2, dist(weibull) time

  estimates store wbl1

streg invest fract polar numst2 format eltime2 caretk2, dist(logn) time

  estimates store lgn1
  
streg invest fract polar numst2 format eltime2 caretk2, dist(ggamma) time

  estimates store gam1

stcox invest fract polar numst2 format eltime2 caretk2, nohr

  estimates store cox1
  

	/*****************************************************/
	/* Now estimate the models accounting for censoring. */
	/*****************************************************/
	
		/* Use observed failure variable. It looks like they    */
		/* mislabelled it in their codebook (i.e., failure=1 	*/
		/* censored=0). CIEP12 and CIEPTW differ in 5 cases	    */
		/* that fail exactly 12 months before the CIEP so we	*/
		/* will use cieptw.                                     */

table cieptw ciep12, row col missing
		
		/* cieptw indicates whether observation prior to 12 */
		/* months before the government must end.           */
		
stset durat, fail(cieptw=1)

  stsum
  stdescribe
  
  sts graph, survival
  sts graph, hazard
  
		/* Rerun the same models - right censoring is       */
		/* accounted for throughout by the -stset- command. */
  
streg invest fract polar numst2 format eltime2 caretk2, dist(exp) time

  estimates store exp0

streg invest fract polar numst2 format eltime2 caretk2, dist(weibull) time

  estimates store wbl0

streg invest fract polar numst2 format eltime2 caretk2, dist(logn) time

  estimates store lgn0
  
streg invest fract polar numst2 format eltime2 caretk2, dist(ggamma) time

  estimates store gam0

stcox invest fract polar numst2 format eltime2 caretk2, nohr

  estimates store cox0

  
	/****************************************************/
	/* Test for gamma model vs log-normal and Weibull.	*/
	/****************************************************/


estimates restore gam1

  ereturn display
  
		/* Test for Weibull model. */

    test [kappa]_b[_cons] = 1
  
		/* Test for log-normal model. */

    test [kappa]_b[_cons] = 0

		/* Test for exponential model. */

    test ([kappa]_b[_cons] = 1) ([ln_sig]_b[_cons]=1)


	/********************************/
	/* Create a table of results.	*/
	/********************************/

		/* Worth installing add-ons for tables. */
	
*ssc install estout
	
estout exp0 wbl0 lgn0 gam0 cox0 exp1 wbl1 lgn1 gam1 cox1 using exercise02continuous.txt, replace ///
	cells(b(star fmt(3)) se(fmt(3) par)) starlevels(* 0.10 ** 0.05) /// 
	stats(N ll, fmt(0 2) label("Observations" "Log-Likelihood")) /// 
	varlabels(_cons constant) ///  
	mlabels(Exp Weibull Log-Normal Gamma Cox Exp Weibull Log-Normal Gamma Cox) ///
	mgroups("Accounting for Censoring with CIEPtw" "Ignoring Censoring", pattern(1 0 0 0 0 1 0 0 0 0)) ///
	transform(-@, pattern(0 0 0 0 1 0 0 0 0 1)) ////
	label varwidth(18) modelwidth(6)

	
	/********************************/
	/* Compare estimated hazards.	*/
	/********************************/


stset durat, fail(cieptw)

  estimates restore wbl0

	stcurve, hazard outfile(exercise02continuous-wbl-cens, replace)

  estimates restore cox0

	stcurve, hazard outfile(exercise02continuous-cox-cens, replace) width(2)

stset durat

  estimates restore wbl1

	stcurve, hazard outfile(exercise02continuous-wbl-nocens, replace)

  estimates restore cox1

	stcurve, hazard outfile(exercise02continuous-cox-nocens, replace) width(2)

		/* Now combine them to compare. */

use exercise02continuous-wbl-cens, clear

	rename haz1 haz_wbl_cens

  merge 1:1 _t using exercise02continuous-wbl-nocens, keep(match master using)

	rename haz1 haz_wbl_nocens
	drop _merge
	
  merge 1:1 _t using exercise02continuous-cox-cens, keep(match master using)

	rename haz1 haz_cox_cens
	drop _merge

  merge 1:1 _t using exercise02continuous-cox-nocens, keep(match master using)

	rename haz1 haz_cox_nocens
	drop _merge
	
		/* Graph the hazards. */
	
  label variable haz_wbl_cens 		"Weibull - Adjusted for CIEP (12 months)"
  label variable haz_wbl_nocens 	"Weibull - No Adjustment for CIEP"
  label variable haz_cox_cens 		"Cox - Adjusted for CIEP (12 months)"
  label variable haz_cox_nocens 	"Cox - No Adjustment for CIEP"

twoway line haz_wbl_cens haz_wbl_nocens haz_cox_cens haz_cox_nocens _t, scheme(s1mono) ///
	lpattern(solid dash solid dash) ///
	lcolor(gs0 gs0 gs8 gs8) ///
	lwidth(medthick medthick medthick medthick) ///
	ylabel(#7, grid) ///
	ytitle(Hazard) ///
	xtitle(Cabinet Duration in Months) ///
	legend(rows(2) size(small)) ///
	note("All variables set to the mean values.", size(vsmall)) ///
	xsize(6) ysize(4) ///
	saving(exercise02continuous, replace)

log close
clear
exit, STATA
