version 14.1
set more off
  quietly log
  local logon = r(status)
  if "`logon'" == "on" { 
	log close 
	}
log using exercise05tvc.log, text replace


/*		****************************************************************	*/
/*     	File Name:		exercise05tvc.do									*/
/*     	Date:   		May 3, 2019											*/
/*      Author: 		Frederick J. Boehmke								*/
/*      Purpose:		Analyze NAFTA position taking with competing risks.	*/
/*      Input File:		exercise05tvc.dta									*/
/*      Output File:	exercise05tvc.log,									*/
/*						exercise05tvc-table.txt								*/
/*						exercise05tvc-table-compare.txt						*/
/*      Requires:		estout.ado											*/		
/*		****************************************************************	*/

	/************************************/
	/* Read in the data and -stset- it.	*/
	/************************************/
 
use exercise05tvc, clear
  
  stset timing

		/* Run the model so we can compare after we -stsplit- and merge. */
  
	streg corptpct labtpct mexbordr dleader rleader ncomact ideol pscenter hhcenter, ///
		dist(weibull) time

		/* We will need to keep track of which person is which and which day     */
		/* they fail. We also want to note that all observations end in failure. */
  
  generat congid = _n
  generat day_ann = timing  
  generat failure = 1

		/* -stset- the data again, referencing the id variable. This then requires */
		/* a failure indicator to mark that all observations (in this case) fail.  */
		
  stset timing, id(congid) failure(failure)

		/* Run the model so we can compare after we -stsplit- and merge. */
  
	streg corptpct labtpct mexbordr dleader rleader ncomact ideol pscenter hhcenter, ///
		dist(weibull) time


	/****************************************************************/
	/* We need a data set with one observation for each MC-day.		*/
	/* We will set it up by hand to illustrate -stset- with TVCs.	*/ 
	/****************************************************************/

		/* Fill in one observation for MC per day. */
		/* Expand creates copies of observations.  */

expand 463

		/* Fill in value of each day for each MC. */

bysort congid: generat day = _n  

		/* Create variable indicating on which day an MC announces. */

generat announce = 1 if day_ann == day
replace announce = 0 if day_ann >  day
replace announce = . if day_ann <  day

		/* Revise failure variable to indicate last day at risk. */
		/* Since all fail this is just a risk set indicator.     */

replace failure  = . if day_ann >  day

  
	/********************************************************/
	/* Now we can run the same analysis with our revised 	*/
	/* data. Until we add a TVC the results should match.	*/
	/********************************************************/

		/* announce() indicates the day they fail while exit() indicates */
		/* that records after the first failure should be ignore. It     */
		/* serves as a risk set marker.                                  */
	
stset day, id(congid) failure(announce) exit(failure)

	streg corptpct labtpct mexbordr dleader rleader ncomact ideol pscenter hhcenter, ///
		dist(weibull) time
		
 
	/********************************************************/
	/* We now create some TVCs measuring observed support.  */
	/********************************************************/

	
generat for = 1 if announce == 1 & vote == 1
generat opposed = 1 if announce == 1 & vote == 0

  tab for opposed, missing

egen numfor_day = sum(for), by(day)
egen numopp_day = sum(opposed), by(day)

xtset congid day

generat numfor_tot = numfor_day if day == 1
bysort congid: replace numfor_tot = l.numfor_tot + numfor_day if day > 1
  
generat numopp_tot = numopp_day if day == 1
bysort congid: replace numopp_tot = l.numopp_tot + numopp_day if day > 1

		/* Now lag them one day. */

generat numfor_tot_l = l.numfor_tot 		
replace numfor_tot_l = 0 if day == 1
generat numopp_tot_l = l.numopp_tot 		
replace numopp_tot_l = 0 if day == 1

		/* Generate lagged net support. */
		
generat numdif_tot_l = numfor_tot_l - numopp_tot_l

  		/* Graph of net support. */

twoway line numdif_tot_l day, scheme(s1color) sort ///
	yline(0) ///
	ylabel(#7, grid) ///
	xtitle(Days After First Announcement) ///
	ytitle(Net Support at Beginning of Day) 

  
	/********************************************************/
	/* Now we can run the same analysis then add TVCs.		*/
	/********************************************************/

	
streg corptpct labtpct mexbordr dleader rleader ncomact ideol pscenter hhcenter, ///
	dist(weibull) time
	 
  estimates store tvc

		/* Add in the TVCs. */

streg corptpct labtpct mexbordr dleader rleader ncomact ideol pscenter hhcenter numdif_tot_l, ///
	dist(weibull) time

  estimates store tvc_dif

streg corptpct labtpct mexbordr dleader rleader ncomact ideol pscenter hhcenter numfor_tot_l numopp_tot_l, ///
	dist(weibull) time
	 
  estimates store tvc_for

  
	/********************************/
	/* Create a table of results.	*/
	/********************************/

	
estout tvc* using exercise05tvc-table.txt, replace ///
	cells(b(star fmt(3)) se(fmt(3) par)) starlevels(* 0.10 ** 0.05) /// 
	stats(N ll, fmt(0 2) label("Observations" "Log-Likelihood")) /// 
	order(numdif_tot_l numfor_tot_l numopp_tot_l) ///
	varlabels(_cons constant) ///
	mlabels(, none) collabels(, none) ///
	mgroups("Time Varying Setup" "Time Invariant Setup", pattern(1 0 0 1 0 0)) ///
	label varwidth(25) modelwidth(8)

  
	/****************************************/
	/* Graph the hazard varying support.	*/
	/****************************************/

	
estimates restore tvc_dif

stcurve, hazard at1(numdif_tot_l=-20) at2(numdif_tot_l=0) at3(numdif_tot_l=20) ///
	ylabel(#5, grid) ///
	xtitle("Days from First Announcement") xline(463) ///
	legend(label(1 "20 Net Opposed") label(2 "Net Support Even") label(3 "20 Net in Favor") ///
	  rows(3) ring(0) bplacement(nw))

		/* Try it with a Cox to compare. */

stcox corptpct labtpct mexbordr dleader rleader ncomact ideol pscenter hhcenter numdif_tot_l, nohr

stcurve, hazard at1(numdif_tot_l=-20) at2(numdif_tot_l=0) at3(numdif_tot_l=20) ///
	ylabel(#5, grid) ///
	xtitle("Days from First Announcement") xline(463) ///
	legend(label(1 "20 Net Opposed") label(2 "Net Support Even") label(3 "20 Net in Favor") ///
	  rows(3) ring(0) bplacement(nw))

	  
	/****************************************************************/
	/* Let's run the incorrect time invariant analysis to compare.	*/
	/* This setup ignores the different values of net support       */
	/* that occured before the actual day of the announcement.      */
	/****************************************************************/

		/* -stset- using one observation per MC - the one from the day of failure. */
	
stset day if day==day_ann

		/* Note that this gives the same result as our earlier file. */

streg corptpct labtpct mexbordr dleader rleader ncomact ideol pscenter hhcenter, ///
	dist(weibull) time

  estimates store tic
  
		/* Now do it with the "TVCs", but incorrectly with one record per subject. */

streg corptpct labtpct mexbordr dleader rleader ncomact ideol pscenter hhcenter numdif_tot_l, ///
	dist(weibull) time

  estimates store tic_dif

streg corptpct labtpct mexbordr dleader rleader ncomact ideol pscenter hhcenter numfor_tot_l numopp_tot_l, ///
	 dist(weibull) time

  estimates store tic_for


	/********************************/
	/* Create a table of results.	*/
	/********************************/

	
estout tvc* tic* using exercise05tvc-table-compare.txt, replace ///
	cells(b(star fmt(3)) se(fmt(3) par)) starlevels(* 0.10 ** 0.05) /// 
	stats(N ll, fmt(0 2) label("Observations" "Log-Likelihood")) /// 
	order(numdif_tot_l numfor_tot_l numopp_tot_l) ///
	varlabels(_cons constant) ///
	mlabels(, none) collabels(, none) ///
	mgroups("Time Varying Setup" "Time Invariant Setup", pattern(1 0 0 1 0 0)) ///
	label varwidth(25) modelwidth(8)

log close
clear
exit, STATA

